@@ -2,7 +2,7 @@
 ;;;
 ;;; Copyright © 2020 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2020, 2021 Rutger van Beusekom <rutger@dezyne.org>
-;;; Copyright © 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -29,18 +29,16 @@
 
   #:use-module (ice-9 match)
 
-  #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
-
-  #:use-module (dzn config)
+  #:use-module (dzn ast goops)
+  #:use-module (dzn ast)
+  #:use-module (dzn code c++)
   #:use-module (dzn code dzn)
   #:use-module (dzn code)
   #:use-module (dzn code-util)
-  #:use-module (dzn code c++)
+  #:use-module (dzn config)
   #:use-module (dzn misc)
-  #:use-module (dzn templates)
-  #:use-module (dzn goops)
-  #:use-module (dzn ast)
-  #:use-module (dzn shell-util))
+  #:use-module (dzn shell-util)
+  #:use-module (dzn templates))
 
 (define-templates-macro define-templates c++-exception-wrappers)
 (include-from-path "dzn/templates/dzn.scm")
@@ -55,7 +53,7 @@
   (let ((type ((compose .type .signature .event) o)))
     (match type
       (($ <bool>) "false")
-      (($ <int>) (.from (.range type)))
+      (($ <subint>) (.from (.range type)))
       (($ <enum>) (append (code:type-name type) (list (last (ast:field* type))))))))
 
 (define-method (c++ew:valued-event? (o <trigger>))
@@ -111,7 +109,7 @@
 (define* (ast-> root #:key (dir ".") model)
   "Entry point."
 
-  (let ((root (code:normalize root)))
+  (let ((root (code:om root)))
     (let* ((generator (code-util:indenter (cute x:header root)))
            (base (basename (ast:source-file root) ".dzn"))
            (file-name (code-util:file-name base dir "_exception_forwarding.hh")))
