@@ -2,6 +2,7 @@
 //
 // Copyright © 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
 // Copyright © 2020, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+// Copyright © 2023 Rutger van Beusekom <rutger@dezyne.org>
 //
 // This file is part of Dezyne.
 //
@@ -20,10 +21,13 @@
 //
 #include "library_foreign.hh"
 
+#include <dzn/locator.hh>
+#include <dzn/runtime.hh>
+
 namespace library {
 
   foreign::foreign(const dzn::locator& dzn_locator)
-  : dzn_meta{"","foreign",0,0,{},{},{[this]{w.check_bindings();}}}
+  : dzn_meta{"","foreign",0,{},{},{[this]{w.check_bindings();}}}
   , dzn_rt(dzn_locator.get<dzn::runtime>())
   , dzn_locator(dzn_locator)
   , w({{"w",&w,this,&dzn_meta},{"",0,0,0}})
